@@ -24,7 +24,7 @@ class ProviderLogHandler(logging.Handler):
         self.group = group
         self.stream = stream.replace(":", "__")
         self.client = session.client("logs")
-        self.sequence_token = ""
+        self.sequence_token = ""  # nosec
 
     @classmethod
     def _get_existing_logger(cls) -> Optional["ProviderLogHandler"]:
@@ -35,7 +35,10 @@ class ProviderLogHandler(logging.Handler):
 
     @classmethod
     def setup(
-        cls, request: HandlerRequest, provider_sess: Optional[SessionProxy]
+        cls,
+        request: HandlerRequest,
+        provider_sess: Optional[SessionProxy],
+        log_format: Optional[logging.Formatter] = None,
     ) -> None:
         log_group = request.requestData.providerLogGroupName
         if request.stackId and request.requestData.logicalResourceId:
@@ -50,11 +53,16 @@ class ProviderLogHandler(logging.Handler):
                 # we just refresh the client with new creds
                 log_handler.client = provider_sess.client("logs")
                 return
+
             # filter provider messages from platform
             provider = request.resourceType.replace("::", "_").lower()
             log_handler = cls(
                 group=log_group, stream=stream_name, session=provider_sess
             )
+
+            if log_format:
+                log_handler.setFormatter(log_format)
+
             # add log handler to root, so that provider gets plugin logs too
             logging.getLogger().addHandler(log_handler)
             logging.getLogger().handlers[0].addFilter(ProviderFilter(provider))
@@ -114,7 +122,10 @@ class HookProviderLogHandler(ProviderLogHandler):
 
     @classmethod
     def setup(  # type: ignore
-        cls, request: HookInvocationRequest, provider_sess: Optional[SessionProxy]
+        cls,
+        request: HookInvocationRequest,
+        provider_sess: Optional[SessionProxy],
+        log_format: Optional[logging.Formatter] = None,
     ) -> None:
         log_group = request.requestData.providerLogGroupName
         if request.stackId and request.requestData.targetLogicalId:
@@ -129,11 +140,16 @@ class HookProviderLogHandler(ProviderLogHandler):
                 # we just refresh the client with new creds
                 log_handler.client = provider_sess.client("logs")
                 return
+
             # filter provider messages from platform
             provider = request.hookTypeName.replace("::", "_").lower()
             logging.getLogger().handlers[0].addFilter(ProviderFilter(provider))
             log_handler = cls(
                 group=log_group, stream=stream_name, session=provider_sess
             )
+
+            if log_format:
+                log_handler.setFormatter(log_format)
+
             # add log handler to root, so that provider gets plugin logs too
             logging.getLogger().addHandler(log_handler)
